@@ -3,6 +3,7 @@ from hdx.utilities.dateparse import parse_date
 from hdx.utilities.downloader import Download
 from hdx.utilities.errors_onexit import ErrorsOnExit
 
+from hdx.scraper.base_scraper import BaseScraper
 from hdx.scraper.runner import Runner
 
 from .conftest import check_scrapers, run_check_scraper
@@ -11,6 +12,7 @@ from .unhcr_myanmar_idps import idps_post_run
 
 class TestScraperNational:
     def test_get_tabular_national(self, configuration, fallbacks):
+        BaseScraper.population_lookup = dict()
         with Download(user_agent="test") as downloader:
             today = parse_date("2020-10-01")
             adminone = AdminOne(configuration)
@@ -359,17 +361,29 @@ class TestScraperNational:
 
             name = "ourworldindata"
             headers = (
-                ["TotalDosesAdministered"],
-                ["#capacity+doses+administered+total"],
+                [
+                    "TotalDosesAdministered",
+                    "PopulationCoverageAdministeredDoses",
+                ],
+                [
+                    "#capacity+doses+administered+total",
+                    "#capacity+doses+administered+coverage+pct",
+                ],
             )
-            values = [dict()]
+            values = [dict(), dict()]
             sources = [
                 (
                     "#capacity+doses+administered+total",
                     "2020-10-01",
                     "Our World in Data",
                     "tests/fixtures/ourworldindata_vaccinedoses.csv",
-                )
+                ),
+                (
+                    "#capacity+doses+administered+coverage+pct",
+                    "2020-10-01",
+                    "Our World in Data",
+                    "tests/fixtures/ourworldindata_vaccinedoses.csv",
+                ),
             ]
             run_check_scraper(name, runner, level, headers, values, sources)
 
@@ -435,17 +449,29 @@ class TestScraperNational:
             runner.add_configurables(scraper_configuration, level)
             name = "ourworldindata"
             headers = (
-                ["TotalDosesAdministered"],
-                ["#capacity+doses+administered+total"],
+                [
+                    "TotalDosesAdministered",
+                    "PopulationCoverageAdministeredDoses",
+                ],
+                [
+                    "#capacity+doses+administered+total",
+                    "#capacity+doses+administered+coverage+pct",
+                ],
             )
-            values = [{"AFG": "240000"}]
+            values = [{"AFG": 240000}, {"AFG": "0.0032"}]
             sources = [
                 (
                     "#capacity+doses+administered+total",
                     "2021-05-03",
                     "Our World in Data",
                     "tests/fixtures/ourworldindata_vaccinedoses.csv",
-                )
+                ),
+                (
+                    "#capacity+doses+administered+coverage+pct",
+                    "2021-05-03",
+                    "Our World in Data",
+                    "tests/fixtures/ourworldindata_vaccinedoses.csv",
+                ),
             ]
             run_check_scraper(name, runner, level, headers, values, sources)
 
